summaryrefslogtreecommitdiffstats
path: root/python/pykde/extra/kde301/ktoolbarbutton.h
diff options
context:
space:
mode:
Diffstat (limited to 'python/pykde/extra/kde301/ktoolbarbutton.h')
-rw-r--r--python/pykde/extra/kde301/ktoolbarbutton.h70
1 files changed, 35 insertions, 35 deletions
diff --git a/python/pykde/extra/kde301/ktoolbarbutton.h b/python/pykde/extra/kde301/ktoolbarbutton.h
index bb6806b2..732bda47 100644
--- a/python/pykde/extra/kde301/ktoolbarbutton.h
+++ b/python/pykde/extra/kde301/ktoolbarbutton.h
@@ -24,10 +24,10 @@
#ifndef _KTOOLBARBUTTON_H
#define _KTOOLBARBUTTON_H
-#include <qpixmap.h>
-#include <qtoolbutton.h>
-#include <qintdict.h>
-#include <qstring.h>
+#include <tqpixmap.h>
+#include <tqtoolbutton.h>
+#include <tqintdict.h>
+#include <tqstring.h>
#include <kglobal.h>
class KToolBar;
@@ -58,8 +58,8 @@ public:
* @param name This button's internal name
* @param txt This button's text (in a tooltip or otherwise)
*/
- KToolBarButton(const QString& icon, int id, QWidget *parent,
- const char *name=0L, const QString &txt=QString::null,
+ KToolBarButton(const TQString& icon, int id, TQWidget *parent,
+ const char *name=0L, const TQString &txt=TQString::null,
KInstance *_instance = KGlobal::instance());
/**
@@ -73,8 +73,8 @@ public:
* @param name This button's internal name
* @param txt This button's text (in a tooltip or otherwise)
*/
- KToolBarButton(const QPixmap& pixmap, int id, QWidget *parent,
- const char *name=0L, const QString &txt=QString::null);
+ KToolBarButton(const TQPixmap& pixmap, int id, TQWidget *parent,
+ const char *name=0L, const TQString &txt=TQString::null);
/**
* Construct a separator button
@@ -82,7 +82,7 @@ public:
* @param parent This button's parent
* @param name This button's internal name
*/
- KToolBarButton(QWidget *parent=0L, const char *name=0L);
+ KToolBarButton(TQWidget *parent=0L, const char *name=0L);
/**
* Standard destructor
@@ -99,8 +99,8 @@ public:
*
* @param pixmap The active pixmap
*/
- // this one is from QButton, so #ifdef-ing it out doesn't break BC
- virtual void setPixmap(const QPixmap &pixmap);
+ // this one is from TQButton, so #ifdef-ing it out doesn't break BC
+ virtual void setPixmap(const TQPixmap &pixmap);
/**
* @deprecated
@@ -109,7 +109,7 @@ public:
*
* @param pixmap The pixmap to use as the default (normal) one
*/
- void setDefaultPixmap(const QPixmap& pixmap);
+ void setDefaultPixmap(const TQPixmap& pixmap);
/**
* @deprecated
@@ -118,7 +118,7 @@ public:
*
* @param pixmap The pixmap to use when disabled
*/
- void setDisabledPixmap(const QPixmap& pixmap);
+ void setDisabledPixmap(const TQPixmap& pixmap);
#endif
/**
@@ -127,7 +127,7 @@ public:
*
* @param text The button (or tooltip) text
*/
- virtual void setText(const QString &text);
+ virtual void setText(const TQString &text);
/**
* Set the icon for this button. The icon will be loaded internally
@@ -135,18 +135,18 @@ public:
*
* @param icon The name of the icon
*/
- virtual void setIcon(const QString &icon);
+ virtual void setIcon(const TQString &icon);
- virtual void setIcon( const QPixmap &pixmap )
- { return QToolButton::setIcon( pixmap ); }
+ virtual void setIcon( const TQPixmap &pixmap )
+ { return TQToolButton::setIcon( pixmap ); }
/**
* Set the pixmaps for this toolbar button from a QIconSet.
* If you call this you don't need to call any of the other methods
* that set icons or pixmaps.
* @param iconset The iconset to use
*/
- virtual void setIconSet( const QIconSet &iconset );
+ virtual void setIconSet( const TQIconSet &iconset );
#ifndef KDE_NO_COMPAT
/**
@@ -160,7 +160,7 @@ public:
* @param generate If true, then the other icons are automagically
* generated from this one
*/
- void setIcon(const QString &icon, bool /*generate*/ ) { setIcon( icon ); }
+ void setIcon(const TQString &icon, bool /*generate*/ ) { setIcon( icon ); }
/**
* @deprecated
@@ -169,7 +169,7 @@ public:
*
* @param icon The icon to use as the default (normal) one
*/
- void setDefaultIcon(const QString& icon);
+ void setDefaultIcon(const TQString& icon);
/**
* @deprecated
@@ -178,7 +178,7 @@ public:
*
* @param icon The icon to use when disabled
*/
- void setDisabledIcon(const QString& icon);
+ void setDisabledIcon(const TQString& icon);
#endif
/**
@@ -205,7 +205,7 @@ public:
/**
* Return a pointer to this button's popup menu (if it exists)
*/
- QPopupMenu *popup();
+ TQPopupMenu *popup();
/**
* Give this button a popup menu. There will not be a delay when
@@ -219,7 +219,7 @@ public:
* @param p The new popup menu
* @param toggle if true, makes the button "sticky" (toggled)
*/
- void setPopup (QPopupMenu *p, bool toggle = false);
+ void setPopup (TQPopupMenu *p, bool toggle = false);
/**
* Gives this button a delayed popup menu.
@@ -235,7 +235,7 @@ public:
* @param p the new popup menu
* @param toggle if true, makes the button "sticky" (toggled)
*/
- void setDelayedPopup(QPopupMenu *p, bool toggle = false);
+ void setDelayedPopup(TQPopupMenu *p, bool toggle = false);
/**
* Turn this button into a radio button
@@ -268,18 +268,18 @@ public slots:
* orientation changing, etc.
*/
void modeChange();
- virtual void setTextLabel(const QString&, bool tipToo);
+ virtual void setTextLabel(const TQString&, bool tipToo);
protected:
- void paletteChange(const QPalette &);
- void leaveEvent(QEvent *e);
- void enterEvent(QEvent *e);
- void drawButton(QPainter *p);
- bool eventFilter (QObject *o, QEvent *e);
+ void paletteChange(const TQPalette &);
+ void leaveEvent(TQEvent *e);
+ void enterEvent(TQEvent *e);
+ void drawButton(TQPainter *p);
+ bool eventFilter (TQObject *o, TQEvent *e);
void showMenu();
- QSize sizeHint() const;
- QSize minimumSizeHint() const;
- QSize minimumSize() const;
+ TQSize sizeHint() const;
+ TQSize minimumSizeHint() const;
+ TQSize minimumSize() const;
bool isRaised() const;
bool isActive() const;
@@ -303,7 +303,7 @@ private:
* @internal
* @version $Id: ktoolbarbutton.h,v 1.21.2.1 2002/04/28 20:59:16 wtrobin Exp $
*/
-class KToolBarButtonList : public QIntDict<KToolBarButton>
+class KToolBarButtonList : public TQIntDict<KToolBarButton>
{
public:
KToolBarButtonList();
@@ -135,18 +135,18 @@ public:
/**
- * Set the pixmaps for this toolbar button from a QIconSet.
+ * Set the pixmaps for this toolbar button from a TQIconSet.
* If you call this you don't need to call any of the other methods
* that set icons or pixmaps.